==> tuia-advert-center-api-1.5.0-20180622.035410-11-sources.jar: cn/com/duiba/tuia/core/api/dto/advertiser/req/ReqPageQueryAdvertiserDto.java <==
/**
 * 文件名： PageQueryAdvertiesReq.java 此类描述的是： 作者: leiliang 创建时间: 2016年4月1日 下午1:53:11
 */
package cn.com.duiba.tuia.core.api.dto.advertiser.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.List;

import cn.com.duiba.tuia.core.api.statistics.domain.BaseQueryReq;


/**
 * 分页查询广告主请求参数.
 *
 * @author huangch
 */
@ApiModel("分页查询广告主请求参数")
public class ReqPageQueryAdvertiserDto extends BaseQueryReq {


    private static final long serialVersionUID = 9205316308452104118L;

    /** 公司名称. */
    private String companyName;
    
    /**
     * 邮箱.
     */
    private String email;

    /**
     * 审核状态.
     */
    private Integer checkStatus;

    /**
     * 邮件状态.
     */
    private Integer emailStatus;

    /**
     * 冻结状态.
     */
    private Integer freezeStatus;

    /**
     * 用户类型.
     */
    private Integer userType;

    /**
     * 广告主/代理商id.
     */
    @ApiModelProperty(hidden = true)
    private Long accountId;

    /**
     * 广告主/代理商ids.
     */
    private List<Long> accountIds;

    /** 账户来源. */
    private Integer accountSource;

    private Long ssoSellId;

    private Long ssoAeId;

    public Long getSsoSellId() {
        return ssoSellId;
    }

    public void setSsoSellId(Long ssoSellId) {
        this.ssoSellId = ssoSellId;
    }

    public Long getSsoAeId() {
        return ssoAeId;
    }

    public void setSsoAeId(Long ssoAeId) {
        this.ssoAeId = ssoAeId;
    }

    /**
     * companyName.
     *
     * @return  the companyName
     * @since   JDK 1.8
     */
    public String getCompanyName() {
        return companyName;
    }
    
    /**
     * companyName.
     *
     * @param   companyName    the companyName to set
     * @since   JDK 1.8
     */
    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
    
    /**
     * accountSource.
     *
     * @return  the accountSource
     * @since   JDK 1.8
     */
    public Integer getAccountSource() {
        return accountSource;
    }
    
    /**
     * accountSource.
     *
     * @param   accountSource    the accountSource to set
     * @since   JDK 1.8
     */
    public void setAccountSource(Integer accountSource) {
        this.accountSource = accountSource;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Integer getEmailStatus() {
        return emailStatus;
    }

    public void setEmailStatus(Integer emailStatus) {
        this.emailStatus = emailStatus;
    }

    public Integer getFreezeStatus() {
        return freezeStatus;
    }

    public void setFreezeStatus(Integer freezeStatus) {
        this.freezeStatus = freezeStatus;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public List<Long> getAccountIds() {
        return accountIds;
    }

    public void setAccountIds(List<Long> accountIds) {
        this.accountIds = accountIds;
    }
}

==> tuia-advert-center-api-2.0.1-20190123.053704-2-sources.jar: cn/com/duiba/tuia/core/api/dto/advertiser/req/ReqPageQueryAdvertiserDto.java <==
/**
 * 文件名： PageQueryAdvertiesReq.java 此类描述的是： 作者: leiliang 创建时间: 2016年4月1日 下午1:53:11
 */
package cn.com.duiba.tuia.core.api.dto.advertiser.req;

import cn.com.duiba.tuia.core.api.statistics.domain.BaseQueryReq;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.List;


/**
 * 分页查询广告主请求参数.
 *
 * @author huangch
 */
@ApiModel("分页查询广告主请求参数")
public class ReqPageQueryAdvertiserDto extends BaseQueryReq {


    private static final long serialVersionUID = 9205316308452104118L;

    /** 公司名称. */
    private String companyName;
    
    /**
     * 邮箱.
     */
    private String email;

    /**
     * 审核状态.
     */
    private Integer checkStatus;

    /**
     * 邮件状态.
     */
    private Integer emailStatus;

    /**
     * 冻结状态.
     */
    private Integer freezeStatus;

    /**
     * 用户类型.
     */
    private Integer userType;

    /**
     * 广告主/代理商id.
     */
    @ApiModelProperty(hidden = true)
    private Long accountId;

    /**
     * 广告主/代理商ids.
     */
    private List<Long> accountIds;

    /** 账户来源. */
    private Integer accountSource;

    private Long ssoSellId;

    private Long ssoAeId;

    /** 账户等级 */
    private Integer accountLevel;

    public Integer getAccountLevel() {
        return accountLevel;
    }

    public void setAccountLevel(Integer accountLevel) {
        this.accountLevel = accountLevel;
    }

    public Long getSsoSellId() {
        return ssoSellId;
    }

    public void setSsoSellId(Long ssoSellId) {
        this.ssoSellId = ssoSellId;
    }

    public Long getSsoAeId() {
        return ssoAeId;
    }

    public void setSsoAeId(Long ssoAeId) {
        this.ssoAeId = ssoAeId;
    }

    /**
     * companyName.
     *
     * @return  the companyName
     * @since   JDK 1.8
     */
    public String getCompanyName() {
        return companyName;
    }
    
    /**
     * companyName.
     *
     * @param   companyName    the companyName to set
     * @since   JDK 1.8
     */
    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
    
    /**
     * accountSource.
     *
     * @return  the accountSource
     * @since   JDK 1.8
     */
    public Integer getAccountSource() {
        return accountSource;
    }
    
    /**
     * accountSource.
     *
     * @param   accountSource    the accountSource to set
     * @since   JDK 1.8
     */
    public void setAccountSource(Integer accountSource) {
        this.accountSource = accountSource;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public Integer getEmailStatus() {
        return emailStatus;
    }

    public void setEmailStatus(Integer emailStatus) {
        this.emailStatus = emailStatus;
    }

    public Integer getFreezeStatus() {
        return freezeStatus;
    }

    public void setFreezeStatus(Integer freezeStatus) {
        this.freezeStatus = freezeStatus;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public List<Long> getAccountIds() {
        return accountIds;
    }

    public void setAccountIds(List<Long> accountIds) {
        this.accountIds = accountIds;
    }
}
